@@ -206,6 +206,8 @@ class FutureTomwerObjectObserverWidget(
             return
         elif future_tomo_obj.status == "error":
             state = DatasetState.FAILED
+            if future_tomo_obj.job_id is None:
+                details = "Job submission to Slurm has failed. This is likely due to an invalid configuration request, such as requesting a GPU on a partition that does not support GPUs. Please review your configuration and try again."
         elif future_tomo_obj.status == "pending":
             details = "\n".join([details, "pending"])
             state = DatasetState.PENDING
