@@ -95,7 +95,9 @@ class NabuWindow(NabuDialog):
 
         # add center of rotation widget
         self._corWidget = _CORWidget(parent=self)
-        rw = self._widget._mainWidget._configuration._reconstructionWidget
+        rw = (
+            self._widget._mainWidget._nabuSettingsWidget._configuration._reconstructionWidget
+        )
         rw.layout().addWidget(self._corWidget, 99, 0, 1, 2)
 
         self._dataViewer = None
