@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import os
 import argparse
 import logging
 import signal
@@ -12,10 +13,10 @@ from tqdm import tqdm
 
 import silx
 from silx.gui import qt
+from silx.io.url import DataUrl
 
 from nabu.pipeline.config import generate_nabu_configfile
 from nabu.stitching.config import get_default_stitching_config, SECTIONS_COMMENTS
-import os
 from nabu.stitching.config import StitchingType
 
 from tomwer.core.volume.volumefactory import VolumeFactory
@@ -30,6 +31,11 @@ from tomwer.gui.stitching.StitchingWindow import YStitchingWindow as _YStitching
 from tomwer.gui.stitching import action as stitching_action
 from tomwer.gui.cluster.slurm import SlurmSettingsWidget
 from tomwer.core.scan.scanbase import TomwerScanBase
+from tomwer.core.scan.nxtomoscan import NXtomoScan
+from tomwer.core.volume import HDF5Volume
+from tomwer.core.volume import MultiTIFFVolume
+from tomwer.core.volume.volumebase import TomwerVolumeBase
+from tomwer.core.tomwer_object import TomwerObject
 
 
 class MainWidget(qt.QTabWidget):
@@ -125,9 +131,23 @@ class MainWidget(qt.QTabWidget):
     def setStitchingType(self, stitching_type):
         self._stitchingConfigWindow.setStitchingType(stitching_type)
 
+    def getStitchingType(self):
+        return self._stitchingConfigWindow.getStitchingType()
+
     def loadSettings(self, config_file):
         self._stitchingConfigWindow._loadSettings(config_file)
 
+    def get_available_pre_processing_stitching_mode(self):
+        return self._stitchingConfigWindow.get_available_pre_processing_stitching_mode()
+
+    def get_available_post_processing_stitching_mode(self):
+        return (
+            self._stitchingConfigWindow.get_available_post_processing_stitching_mode()
+        )
+
+    def getTomoObjs(self):
+        return self._stitchingConfigWindow.getTomoObjs()
+
 
 class _StitcherThread(qt.QThread):
     DEFAULT_OUTPUT_CONFIG_NAME = "stitching_conf_autosave.conf"
@@ -186,6 +206,9 @@ class _StitcherThread(qt.QThread):
 
 
 class MainWindow(qt.QDialog):
+
+    sigTomoObjAdded = qt.Signal(TomwerObject)
+
     def __init__(self, axis: int, parent=None) -> None:
         super().__init__(parent)
         self.setLayout(qt.QVBoxLayout())
@@ -223,6 +246,26 @@ class MainWindow(qt.QDialog):
         self.layout().addWidget(self._buttons)
         self._buttons.button(qt.QDialogButtonBox.Apply).setText("Launch stitching")
 
+        # set up
+        self._mainWindow._stitchingConfigWindow.setPreProcessingOutput(
+            NXtomoScan(
+                scan=os.path.join(os.getcwd(), "stitching", "stitched.nx"),
+                entry="entry0000",
+            )
+            .get_identifier()
+            .to_str()
+        )
+        self._mainWindow._stitchingConfigWindow.setPostProcessingOutput(
+            HDF5Volume(
+                file_path=os.path.join(
+                    os.getcwd(), "stitching", "stitched_volume.hdf5"
+                ),
+                data_path="stitched_volume",
+            )
+            .get_identifier()
+            .to_str()
+        )
+
         # connect signal / slot
         self._buttons.button(qt.QDialogButtonBox.Apply).clicked.connect(self.accept)
         self._loadConfigurationAction.triggered.connect(
@@ -245,7 +288,22 @@ class MainWindow(qt.QDialog):
         self._mainWindow._stitchingConfigWindow._widget._mainWidget.setCurrentWidget(
             orderedListWidget
         )
-        orderedListWidget._callbackAddTomoObj()
+        tomo_objs = orderedListWidget._callbackAddTomoObj()
+        for tomo_obj in tomo_objs:
+            if len(tomo_objs) > 0:
+                self.__updateStitchingTypeFromObjAdded(tomo_obj=tomo_objs[0])
+
+    def __updateStitchingTypeFromObjAdded(self, tomo_obj: TomwerObject):
+        if isinstance(tomo_obj, TomwerScanBase):
+            self.setStitchingType(self.get_available_pre_processing_stitching_mode()[0])
+        elif isinstance(tomo_obj, TomwerVolumeBase):
+            self.setStitchingType(
+                self.get_available_post_processing_stitching_mode()[0]
+            )
+        else:
+            raise TypeError(
+                f"tomo_obj is expected to be an instance of {type(TomwerObject)}. Got {type(tomo_obj)}"
+            )
 
     def close(self):
         self._mainWindow.close()
@@ -256,8 +314,112 @@ class MainWindow(qt.QDialog):
         self.close()
         super().reject()
 
+    @classmethod
+    def can_write_to_folder(cls, folder_path):
+        if not os.path.exists(folder_path):
+            parent_dir = os.path.dirname(folder_path)
+            if (
+                not parent_dir
+            ):  # If folder_path is just a filename in the current directory
+                parent_dir = os.getcwd()
+            return cls.can_write_to_folder(parent_dir)
+        return os.access(folder_path, os.W_OK)
+
+    def __checkOutputDirWritable(self) -> bool:
+        """Make sure the output directory is writable"""
+        error = None
+        config = self.getStitchingConfiguration()
+
+        stitching_type = self.getStitchingType()
+        if stitching_type in (StitchingType.Y_PREPROC, StitchingType.Z_PREPROC):
+            output_file = config.get("preproc", {}).get("location", "")
+            output_dir, _ = os.path.split(output_file)
+
+        elif stitching_type in (StitchingType.Z_POSTPROC,):
+            output_volume_identifier = config.get("postproc", {}).get(
+                "output_volume", None
+            )
+            if output_volume_identifier:
+                output_volume = VolumeFactory.create_tomo_object_from_identifier(
+                    output_volume_identifier
+                )
+                if isinstance(output_volume, (HDF5Volume, MultiTIFFVolume)):
+                    output_dir = os.path.dirname(output_volume.data_url.file_path())
+                else:
+                    output_dir = output_volume.data_url.file_path()
+            else:
+                output_dir = None
+                error = "No output file/directory defined."
+        else:
+            raise ValueError(f"stitching type {stitching_type!r} not handled.")
+        if output_dir is not None:
+            if not self.can_write_to_folder(output_dir):
+                error = f"No write rights on {output_dir!r}. Unable to save stitching."
+        config.get("preproc")
+
+        if error is None:
+            return True
+
+        error_dialog = qt.QMessageBox()
+        error_dialog.setIcon(qt.QMessageBox.Warning)
+        error_dialog.setWindowTitle("Error - cannot process")
+        error_dialog.setText(error)
+        error_dialog.setInformativeText("Please check your input and try again.")
+        error_dialog.exec()
+        return False
+
+    def __checkStitchingModeSeemsValid(self) -> bool:
+        """
+        Check whether the requested stitching mode matches the input data (pre-processing or post-processing).
+        If not, warn the user and block processing.
+        """
+        warning = None
+        tomo_objs = self._mainWindow.getTomoObjs()
+        stitching_type = self.getStitchingType()
+        if len(tomo_objs) == 0:
+            warning = "No object to be stitched together."
+        else:
+            scans = tuple(
+                filter(
+                    lambda obj: isinstance(obj, TomwerScanBase),
+                    tomo_objs,
+                )
+            )
+            volumes = tuple(
+                filter(
+                    lambda obj: isinstance(obj, TomwerVolumeBase),
+                    tomo_objs,
+                )
+            )
+            if len(scans) > 0 and len(volumes) > 0:
+                warning = "Both scans and volumes to be stitched have been found. It should be one or the other. Processing will fail."
+
+            elif stitching_type in (StitchingType.Y_PREPROC, StitchingType.Z_PREPROC):
+                if len(scans) == 0:
+                    warning = f"No scans found but {stitching_type.value!r} requested. Maybe you want to stitch reconstructed volumes instead of scans ? If so please select 'stitching method' to one of the 'postproc' mode."
+
+            elif stitching_type in (StitchingType.Z_POSTPROC,):
+                if len(volumes) == 0:
+                    warning = f"No volumes found but {stitching_type.value!r} requested. Maybe you want to stitch scans instead of volumes ? If so please select 'stitching method' to one of the 'preproc' mode."
+            else:
+                raise NotImplementedError(
+                    f"No consistency check is available for stitching type: {stitching_type.value}!)"
+                )
+
+        if warning is None:
+            return True
+
+        error_dialog = qt.QMessageBox()
+        error_dialog.setIcon(qt.QMessageBox.Warning)
+        error_dialog.setWindowTitle("Error - cannot process")
+        error_dialog.setText(warning)
+        error_dialog.setInformativeText("Please check your input and try again.")
+        error_dialog.exec()
+        return False
+
     def accept(self):
-        self.process_stitching()
+        if self.__checkStitchingModeSeemsValid() and self.__checkOutputDirWritable():
+            self.process_stitching()
 
     def process_stitching(self):
         self._processingThread = _StitcherThread(
@@ -286,6 +448,9 @@ class MainWindow(qt.QDialog):
     def addTomoObj(self, *args, **kwargs):
         self._mainWindow.addTomoObj(*args, **kwargs)
 
+    def getTomoObjs(self):
+        return self._mainWindow._stitchingConfigWindow.getTomoObjs()
+
     def getClusterConfig(self) -> dict:
         if self._mainWindow._slurmCB.isChecked():
             return self._mainWindow.getClusterConfig()
@@ -298,9 +463,24 @@ class MainWindow(qt.QDialog):
     def setStitchingType(self, stitching_type):
         self._mainWindow.setStitchingType(stitching_type)
 
+    def getStitchingType(self):
+        return self._mainWindow.getStitchingType()
+
     def loadSettings(self, config_file: str):
         self._mainWindow.loadSettings(config_file)
 
+    def setPreProcessingOutput(self, url: DataUrl) -> None:
+        self._mainWindow._stitchingConfigWindow.setPreProcessingOutput(url=url)
+
+    def setPostProcessingOutput(self, url: DataUrl) -> None:
+        self._mainWindow._stitchingConfigWindow.setPostProcessingOutput(url=url)
+
+    def get_available_pre_processing_stitching_mode(self) -> tuple[StitchingType]:
+        return self._mainWindow.get_available_pre_processing_stitching_mode()
+
+    def get_available_post_processing_stitching_mode(self) -> tuple[StitchingType]:
+        return self._mainWindow.get_available_post_processing_stitching_mode()
+
 
 def main(argv, stitcher_name: str, stitching_axis: int, logger):
     parser = argparse.ArgumentParser(description=__doc__)
