@@ -40,40 +40,35 @@ class H5ToNxProcess(
     """
 
     @staticmethod
-    def deduce_output_file_path(master_file_name, scan, entry, outputdir):
+    def deduce_output_file_path(master_file_name, scan, output_dir):
         master_file_name = os.path.abspath(master_file_name)
         # step 1: get output dir
         try:
-            outputdir = ProcessDataOutputDirMode.from_value(outputdir)
+            output_dir = ProcessDataOutputDirMode.from_value(output_dir)
         except ValueError:
             # case path provided directly
-            output_folder = format_output_location(outputdir, scan=scan)
+            output_folder = format_output_location(output_dir, scan=scan)
         else:
-            if outputdir is ProcessDataOutputDirMode.OTHER:
+            if output_dir is ProcessDataOutputDirMode.OTHER:
                 raise ValueError(
                     f"When output dir mode is {ProcessDataOutputDirMode.OTHER} we expect to received the output dir directly"
                 )
-            if outputdir is ProcessDataOutputDirMode.PROCESSED_DATA_FOLDER:
+            if output_dir is ProcessDataOutputDirMode.PROCESSED_DATA_FOLDER:
                 path = pathlib.Path(
                     get_default_output_file(input_file=master_file_name)
                 )
                 output_folder = str(path.parent)
-            elif outputdir is ProcessDataOutputDirMode.IN_SCAN_FOLDER:
+            elif output_dir is ProcessDataOutputDirMode.IN_SCAN_FOLDER:
                 output_folder = os.path.dirname(master_file_name)
             else:
-                raise RuntimeError(f"output dir {outputdir} not handled")
+                raise RuntimeError(f"output dir {output_dir} not handled")
 
-        file_name = os.path.basename(master_file_name)
-        if "." in file_name:
-            file_name = "".join(file_name.split(".")[:-1])
-
-        entry_for_file_name = entry.lstrip("/")
-        entry_for_file_name = entry_for_file_name.replace("/", "_")
-        entry_for_file_name = entry_for_file_name.replace(".", "_")
-        entry_for_file_name = entry_for_file_name.replace(":", "_")
-        output_file_name = "_".join(
-            (os.path.splitext(file_name)[0], entry_for_file_name + ".nx")
-        )
+        # deduce output file from file basename and output directory
+        file_basename = os.path.basename(master_file_name)
+        file_name = os.path.splitext(file_basename)[0]
+        file_name = file_name.replace(".", "_")
+        file_name = file_name.replace(":", "_")
+        output_file_name = file_name + ".nx"
         return os.path.join(output_folder, output_file_name)
 
     def run(self):
