@@ -5,7 +5,7 @@ from collections import namedtuple
 
 import numpy
 from silx.io.url import DataUrl
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from tomoscan.esrf.scan.utils import get_data
 
 from tomwer.core.process.reconstruction.utils.cor import relative_pos_to_absolute
@@ -60,8 +60,8 @@ class AxisCalculationInput(_Enum):
         if type(value) is str and len(value.split("_")) == 2:
             proj_type, pag = value.split("_")
             value_pag = True if pag == _WITH_PAG else False
-            value_proj = ProjectionType.from_value(proj_type)
-            return cls.from_value(_calculation_conf(value_proj, value_pag))
+            value_proj = ProjectionType(proj_type)
+            return cls(_calculation_conf(value_proj, value_pag))
         elif isinstance(value, cls):
             return value
         else:
@@ -348,7 +348,7 @@ class AxisRP:
     @estimated_cor.setter
     def estimated_cor(self, value: Side | float | None):
         try:
-            value = Side.from_value(value)
+            value = Side(value)
         except ValueError:
             pass
         if self.__estimated_cor != value:
