@@ -205,7 +205,7 @@ class _NabuBaseReconstructor:
         axis: NabuPlane = NabuPlane.XY,
     ) -> None:
         self._scan = scan
-        self._target = Target.from_value(target)
+        self._target = Target(target)
         self._dry_run = dry_run
         self._process_name = process_name
         self._process = None
@@ -564,7 +564,7 @@ class _NabuBaseReconstructor:
         )
 
         source = extra_infos.get("source", INormSource.NONE)
-        source = INormSource.from_value(source)
+        source = INormSource(source)
 
         if source is INormSource.NONE:
             pass
