@@ -390,7 +390,7 @@ class _Reconstructor(_NabuBaseReconstructor):
             _config["reconstruction"]["end_z"] = self.slice_index
         else:
             raise ValueError(
-                f"self.axis has an invalid value: {self.axis} when expected to be in {NabuPlane.values()}"
+                f"self.axis has an invalid value: {self.axis} when expected to be in {[item.value for item in NabuPlane]}"
             )
         return _config, file_prefix
 
