@@ -4,9 +4,12 @@ from tomwer.core.process.reconstruction.nabu.utils import (
     get_recons_volume_identifier,
     get_multi_cor_recons_volume_identifiers,
     nabu_std_err_has_error,
+    get_default_output_volume_for_tiff_3d,
 )
 from tomwer.core.scan.edfscan import EDFTomoScan
 from tomwer.core.scan.nxtomoscan import NXtomoScan
+from tomwer.core.volume.edfvolume import EDFVolume
+from tomwer.core.volume.hdf5volume import HDF5Volume
 
 _scans = (
     NXtomoScan(
@@ -135,6 +138,33 @@ def test_get_multi_cor_recons_volume_identifier(scan):
     assert id_rec_vols[10].to_str() == "tiff:volume:/this/is/a?file_prefix=test"
 
 
+def test_get_default_output_volume_for_tiff_3d():
+    """test 'get_default_output_volume_for_tiff_3d' function"""
+    # test from EDF
+    input_edf_volume = EDFVolume(
+        folder="/path/to/my_folder",
+    )
+    assert (
+        get_default_output_volume_for_tiff_3d(
+            input_volume=input_edf_volume,
+            output_dir="/path/to/my_folder",
+        ).data_url.file_path()
+        == "/path/to/my_folder/my_folder.tiff"
+    )
+    # test from hdf5
+    input_hdf5_volume = HDF5Volume(
+        file_path="/path/to/my_file.hdf5",
+        data_path="entry0012",
+    )
+    assert (
+        get_default_output_volume_for_tiff_3d(
+            input_volume=input_hdf5_volume,
+            output_dir="/cast_volume",
+        ).data_url.file_path()
+        == "/cast_volume/my_file.tiff"
+    )
+
+
 def test_nabu_std_err_has_error():
     assert nabu_std_err_has_error(None) is False
     assert nabu_std_err_has_error(b"") is False
@@ -284,3 +314,30 @@ def test_nabu_std_err_has_error():
         )
         is False
     )
+
+    assert (
+        nabu_std_err_has_error(
+            b"""UserWarning: The CUDA compiler succeeded, but said the following:
+            kernel.cu(228): warning #177-D: variable "x_stop_other" was declared but never referenced
+            int x_stop_other = other_x_range.y;
+
+            Remark: The warnings can be suppressed with "-diag-suppress <warning-number>"
+
+            kernel.cu(230): warning #177-D: variable "y_stop_other" was declared but never referenced
+            int y_stop_other = other_y_range.y;
+
+            self.module = SourceModule(self.src, **self.sourcemodule_kwargs)
+            /cvmfs/tomo.esrf.fr/software/packages/ubuntu24.04/x86_64/tomotools/2025_08_13_stable/lib/python3.12/site-packages/nabu/cuda/kernel.py:58: UserWarning: The CUDA compiler succeeded, but said the following:
+            kernel.cu(228): warning #177-D: variable "x_stop_other" was declared but never referenced
+            int x_stop_other = other_x_range.y;
+
+            Remark: The warnings can be suppressed with "-diag-suppress <warning-number>"
+
+            kernel.cu(230): warning #177-D: variable "y_stop_other" was declared but never referenced
+            int y_stop_other = other_y_range.y;
+
+            self.module = SourceModule(self.src, **self.sourcemodule_kwargs)
+            """
+        )
+        is False
+    )
