@@ -13,16 +13,19 @@ from nabu.pipeline.fullfield.nabu_config import (
 from enum import Enum
 
 from tomoscan.identifier import VolumeIdentifier
+from tomoscan.volumebase import VolumeBase
 import tomwer.version
 from tomwer.core.process.reconstruction.nabu.plane import NabuPlane
+from tomwer.core.process.output import NabuOutputFileFormat
 from tomwer.core.scan.edfscan import EDFTomoScan
 from tomwer.core.scan.nxtomoscan import NXtomoScan
 from tomwer.core.scan.scanbase import TomwerScanBase
+from tomwer.core.volume.volumebase import TomwerVolumeBase
 from tomwer.core.volume.edfvolume import EDFVolume
 from tomwer.core.volume.hdf5volume import HDF5Volume
 from tomwer.core.volume.jp2kvolume import JP2KVolume
 from tomwer.core.volume.rawvolume import RawVolume
-from tomwer.core.volume.tiffvolume import TIFFVolume
+from tomwer.core.volume.tiffvolume import TIFFVolume, MultiTIFFVolume
 
 _logger = logging.getLogger(__name__)
 
@@ -97,7 +100,7 @@ def get_nabu_about_desc(overwrite: bool) -> dict:
 def get_recons_volume_identifier(
     file_prefix: str,
     location: str,
-    file_format: str,
+    file_format: str | NabuOutputFileFormat,
     scan: TomwerScanBase,
     slice_index: int | None,
     axis: NabuPlane,
@@ -106,6 +109,8 @@ def get_recons_volume_identifier(
     return tuple of DataUrl for existings slices
     """
     axis = NabuPlane.from_value(axis)
+    if isinstance(file_format, NabuOutputFileFormat):
+        file_format = file_format.value
     file_format = file_format.lower()
     if file_format in ("hdf5", "h5", "hdf"):
         if slice_index is not None:
@@ -160,6 +165,22 @@ def get_recons_volume_identifier(
                 volume_basename=basename,
             ),
         )
+    elif file_format == "tiff3d":
+        if slice_index is not None:
+            # case of a single hdf5 file
+            file_name = "_".join(
+                (file_prefix, "plane", axis.value, str(slice_index).zfill(6))
+            )
+        else:
+            file_name = file_prefix
+        file_name = ".".join((file_name, "tiff"))
+        file_path = os.path.join(location, file_name)
+
+        volumes = (
+            MultiTIFFVolume(
+                file_path=file_path,
+            ),
+        )
 
     else:
         raise ValueError(f"file format not managed: {file_format}")
@@ -342,6 +363,7 @@ class _NabuPhaseMethod(Enum):
     PAGANIN = "Paganin"
     CTF = "CTF"
     NONE = "None"
+    CONE = "cone"
 
     @classmethod
     def from_value(cls, value):
@@ -412,6 +434,9 @@ def nabu_std_err_has_error(errs: bytes | None):
             or (
                 "Performing MLEM" in line and "iterations" in line
             )  # corrct usage of tqdm (goes to stderr)
+            or "Remark: The" in line
+            or "int x_stop_other = other_x_range.y;" in line
+            or "int y_stop_other = other_y_range.y;" in line
         )
 
     if errs is None:
@@ -419,6 +444,7 @@ def nabu_std_err_has_error(errs: bytes | None):
     else:
         for line in errs.decode("UTF-8").split("\n"):
             if not ignore(line):
+                print("\n\nline is", line)
                 return True
     return False
 
@@ -518,3 +544,84 @@ def get_nabu_multicor_file_prefix(scan):
         raise ValueError(f"dataset location {scan.path} is neither a file or directory")
     file_prefix += "_rec"  # avoid overwriting dataset
     return file_prefix
+
+
+def update_nabu_config_for_tiff_3d(config: dict) -> None:
+    """
+    Adapts the nabu configuration for 3D TIFF file format.
+
+    Nabu currently distinguishes TIFF files as either single-file or multi-file,
+    but does not natively support the concept of a 3D TIFF format. This function
+    bridges that gap by adjusting the configuration to handle 3D TIFF files
+    as a single logical unit.
+    """
+    file_format = NabuOutputFileFormat(
+        config.get("output", {}).get("file_format", "tiff")
+    )
+    if file_format is NabuOutputFileFormat.TIFF_3D:
+        config["output"]["file_format"] = "tiff"
+        config["output"]["tiff_single_file"] = "1"
+        _logger.debug("Mapping tiff3d -> nabu tiff + tiff_single_file=1")
+
+
+def from_nabu_config_to_file_format(nabu_config) -> NabuOutputFileFormat:
+    """
+    Infers the file format from a Nabu configuration dictionary.
+
+    This function is specifically designed to handle the special case of 3D TIFF files. See 'update_nabu_config_for_tiff_3d'
+    """
+    file_format = NabuOutputFileFormat(nabu_config["output"]["file_format"])
+    tiff_single_file = nabu_config["output"].get("tiff_single_file", False)
+    if tiff_single_file in (True, 1, "1") and file_format is NabuOutputFileFormat.TIFF:
+        return NabuOutputFileFormat.TIFF_3D
+    else:
+        return file_format
+
+
+def get_default_output_volume_for_tiff_3d(
+    input_volume: TomwerVolumeBase, output_dir: str
+) -> TomwerVolumeBase:
+    """
+    Does what nabu.io.cast_volume.get_default_output_volume does but for for 3d-tiff
+    For a given input volume and output type return output volume as an instance of VolumeBase
+
+    :param intput_volume: volume for which we want to get the resulting output volume for a cast
+    :param output_dir: output dir to save the cast volume
+    """
+    if not isinstance(input_volume, VolumeBase):
+        raise TypeError(f"input_volume is expected to be an instance of {VolumeBase}")
+
+    if isinstance(input_volume, (EDFVolume, TIFFVolume, JP2KVolume)):
+        file_path = os.path.join(
+            input_volume.data_url.file_path(),
+            output_dir,
+            input_volume.get_volume_basename() + ".tiff",
+        )
+        volume = MultiTIFFVolume(
+            file_path=file_path,
+        )
+        assert (
+            volume.get_identifier() is not None
+        ), "volume should be able to create an identifier"
+        return volume
+
+    elif isinstance(input_volume, (HDF5Volume, MultiTIFFVolume)):
+        data_file_parent_path, data_file_name = os.path.split(
+            input_volume.data_url.file_path()
+        )
+        # replace extension:
+        data_file_name = ".".join(
+            [
+                os.path.splitext(data_file_name)[0],
+                "tiff",
+            ]
+        )
+        volume = MultiTIFFVolume(
+            file_path=os.path.join(data_file_parent_path, output_dir, data_file_name),
+        )
+        assert (
+            volume.get_identifier() is not None
+        ), "volume should be able to create an identifier"
+        return volume
+    else:
+        raise NotImplementedError(f"input volume format {input_volume} is not handled")
