@@ -127,9 +127,9 @@ class EDFTomoScan(_tsEDFTomoScan, TomwerScanBase):
             )
         return EDFTomoScan(scan=identifier.folder)
 
-    def clear_caches(self):
-        _tsEDFTomoScan.clear_caches(self)
-        TomwerScanBase.clear_caches(self)
+    def clear_cache(self):
+        _tsEDFTomoScan.clear_cache(self)
+        TomwerScanBase.clear_cache(self)
 
     @staticmethod
     def directory_contains_scan(directory, src_pattern, dest_pattern):
