@@ -10,7 +10,7 @@ from typing import Iterable
 
 import numpy
 from silx.io.url import DataUrl
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from tomoscan.identifier import VolumeIdentifier
 from tomoscan.normalization import IntensityNormalization
@@ -92,10 +92,10 @@ class TomwerScanBase(TomwerObject):
         """
         raise NotImplementedError("Base class")
 
-    def clear_caches(self):
+    def clear_cache(self):
         self._cache_proj_urls = None
         self._notify_ffc_rsc_missing = True
-        super().clear_caches()
+        super().clear_cache()
 
     def _flat_field_correction(
         self,
