@@ -374,7 +374,7 @@ class SlurmSettingsWidget(qt.QWidget):
             All of the user's environment will be loaded (either from the caller's environment or from a clean environment if --get-user-env is specified). \nCan fail when submitting cross-platform jobs and user has some module loaded
             """,
         )
-        self._exportValueCM.setCurrentText("NONE")
+        self._exportValueCM.setCurrentText("ALL")
         self._sbatchAdvancedParameters.layout().addRow("--export", self._exportValueCM)
         self.layout().addWidget(self._warning_opd_export_opts, 16, 2, 1, 1)
 
