@@ -616,7 +616,7 @@ class _TomwerObjectList(qt.QTableWidget):
         self.setDisplayMode(DisplayMode.SHORT)
 
     def setDisplayMode(self, mode: DisplayMode) -> None:
-        self._displayMode = DisplayMode.from_value(mode)
+        self._displayMode = DisplayMode(mode)
         self._update()
 
     def n_data(self):
