@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import os
 import socket
+import logging
 
 from silx.gui import qt
 
@@ -21,6 +22,9 @@ from tomwer.gui.utils.inputwidget import (
 from tomwer.synctools.rsyncmanager import BlissSequenceRSyncWorker
 
 
+_logger = logging.getLogger(__name__)
+
+
 class DataListenerWidget(qt.QMainWindow):
     """
     Widget to display the bliss acquisition on going and finished
@@ -42,7 +46,7 @@ class DataListenerWidget(qt.QMainWindow):
     sigCFGFileChanged = qt.Signal(str)
     """Signal emitted when path to the nxtomomill configuration file change"""
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, host_discovery=None):
         qt.QMainWindow.__init__(self, parent)
         self.setWindowFlags(qt.Qt.Widget)
         self._listener = None
@@ -66,7 +70,9 @@ class DataListenerWidget(qt.QMainWindow):
         """Widget containing the latest valid scan found by the listener"""
         self._centralWidget.layout().addWidget(self._historyWindow)
 
-        self._configWindow = ConfigurationWidget(parent=self)
+        self._configWindow = ConfigurationWidget(
+            parent=self, host_discovery=host_discovery
+        )
         """Widget containing the configuration to communicate with bliss"""
         self._centralWidget.layout().addWidget(self._configWindow)
 
@@ -113,6 +119,12 @@ class DataListenerWidget(qt.QMainWindow):
         self._controlAction.setChecked(True)
         self._updateCentralWidget(self._controlAction)
 
+    def setHostAndPortToolTip(self, tooltip: str):
+        self._configWindow._hostQLE.setToolTip(tooltip)
+        self._configWindow._hostLabel.setToolTip(tooltip)
+        self._configWindow._portLabel.setToolTip(tooltip)
+        self._configWindow._portSpinBox.setToolTip(tooltip)
+
     def getHost(self) -> str:
         """Return server host"""
         return self._configWindow.getHost()
@@ -124,7 +136,7 @@ class DataListenerWidget(qt.QMainWindow):
     def getBlissServerConfiguration(self) -> dict:
         return self._configWindow.getConfiguration()
 
-    def setBlissServerConfiguation(self, config):
+    def setBlissServerConfiguration(self, config):
         self._configWindow.setConfiguration(config=config)
 
     def setCFGFilePath(self, cfg_file):
@@ -297,7 +309,7 @@ class DataListenerControl(qt.QWidget):
     def isActivate(self):
         return self._button.text() == "stop"
 
-    def activate(self, activate=True):
+    def activate(self, activate=True, *args, **kwargs):
         self._updateIconAndText(activate=activate)
         if activate is True:
             self.sigActivated.emit()
@@ -321,7 +333,12 @@ class ConfigurationWidget(qt.QDialog):
     sigConfigurationChanged = qt.Signal()
     """Signal emitted when the configuration change"""
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, host_discovery: str | None = None):
+        """
+        :param host_discovery: define a policy regarding host discovery when creating the widget. If None no discovery will be made.
+            If 'BEACON_HOST' given then will try to discover the host name and port using the environment variable BEACON_HOST.
+        """
+
         qt.QDialog.__init__(self, parent)
         self.setLayout(qt.QGridLayout())
 
@@ -389,11 +406,27 @@ class ConfigurationWidget(qt.QDialog):
 
         # set up
         self._buttons.hide()
-        if settings.JSON_RPC_HOST is None:
-            self.setHost(socket.gethostname())
-        else:
+        if settings.JSON_RPC_HOST is not None:
+            # if defined in the settings file simply take it
             self.setHost(settings.JSON_RPC_HOST)
-        self.setPort(settings.JSON_RPC_PORT)
+            self.setPort(settings.JSON_RPC_PORT)
+        elif host_discovery is None:
+            self.setHost(socket.gethostname())
+            self.setPort(settings.JSON_RPC_PORT)
+        else:
+            err_beacon_host = "Unable to determine host name and host port from 'BEACON_HOST'. Please export it as host_name:host_port. For example 'export BEACON_HOST=icc:0000'"
+            beacon_host = os.environ.get("BEACON_HOST")
+            if beacon_host is None:
+                _logger.error(err_beacon_host)
+            else:
+                try:
+                    host_name, host_port = beacon_host.split(":")
+                    host_port = int(host_port)
+                except ValueError:
+                    _logger.error(err_beacon_host)
+                else:
+                    self.setHost(host_name)
+                    self.setPort(host_port)
 
     def getCFGFilePath(self):
         return self._cfgWidget.getCFGFilePath()
