@@ -1042,7 +1042,7 @@ class _BinSubSampling(qt.QGroupBox):
             "Binning factor in the horizontal dimension when reading the data. \nThe final slices dimensions will be divided by this factor."
         )
         # z binning
-        self._zBinningSB = qt.QSpinBox(self)
+        self._zBinningSB = QSpinBoxIgnoreWheel(self)
         self._zBinningSB.setMinimum(1)
         self._zBinningSB.setMaximum(100)
         self.layout().addRow("vertical binning", self._zBinningSB)
