@@ -10,7 +10,7 @@ from nabu.pipeline.fullfield.nabu_config import (
 )
 from silx.gui import icons as silx_icons
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from nxtomo.nxobject.nxdetector import FOV
 
 from tomwer.core.utils.dictutils import concatenate_dict
@@ -56,7 +56,7 @@ class _NabuStages(_Enum):
     @staticmethod
     def getProcessEnum(stage):
         """Return the process Enum associated to the stage"""
-        stage = _NabuStages.from_value(stage)
+        stage = _NabuStages(stage)
         if stage is _NabuStages.INI:
             raise NotImplementedError()
         elif stage is _NabuStages.PRE:
@@ -113,8 +113,8 @@ class _NabuProcess(qt.QWidget):
         qt.QWidget.__init__(self, parent=parent)
         self.setLayout(qt.QGridLayout())
         self._stageCB = qt.QComboBox(parent=self)
-        for stage in _NabuStages.values():
-            self._stageCB.addItem(stage)
+        for stage in _NabuStages:
+            self._stageCB.addItem(stage.value)
 
         self.layout().addWidget(qt.QLabel("stage:", self), 0, 0, 1, 1)
         self.layout().addWidget(self._stageCB, 0, 1, 1, 1)
@@ -147,7 +147,7 @@ class _NabuConfiguration(qt.QWidget):
             self.addStage(stage=stage, processes=processes)
 
     def addStage(self, stage, processes):
-        stage = _NabuStages.from_value(value=stage)
+        stage = _NabuStages(value=stage)
         for process in processes:
             _NabuStages.getProcessEnum(stage=stage)
 
@@ -323,7 +323,7 @@ class NabuWindow(qt.QMainWindow):
         self._mainWidget.nabuSettingsWidget._configuration._preProcessingWidget._sinoRingsOpts.resetConfiguration()
         default_config["tomwer_slices"] = "middle"
         default_config["preproc"]["ccd_filter_enabled"] = False
-        default_config["preproc"]["double_flatfield_enabled"] = False
+        default_config["preproc"]["double_flatfield"] = False
         default_config["preproc"]["flatfield"] = True
         default_config["preproc"]["take_logarithm"] = True
         self.setConfiguration(default_config)
@@ -377,7 +377,7 @@ class NabuWindow(qt.QMainWindow):
         return self._filterAction.isChecked()
 
     def setConfigurationLevel(self, level):
-        level = ConfigurationLevel.from_value(level)
+        level = ConfigurationLevel(level)
         if level == ConfigurationLevel.REQUIRED:
             self._minimalisticAction.setChecked(True)
         elif level == ConfigurationLevel.ADVANCED:
@@ -436,7 +436,7 @@ class NabuWidget(qt.QWidget):
 
     def __init__(self, parent, flow_direction="vertical"):
         qt.QWidget.__init__(self, parent=parent)
-        flow_direction = FlowDirection.from_value(flow_direction)
+        flow_direction = FlowDirection(flow_direction)
         self.setLayout(qt.QGridLayout())
         self._filteringActive = True
         self._configuration_level = ConfigurationLevel.OPTIONAL
@@ -485,7 +485,7 @@ class NabuWidget(qt.QWidget):
             qt.QSizePolicy.Minimum, qt.QSizePolicy.Minimum
         )
         self._configurationScrollArea.setSizePolicy(
-            qt.QSizePolicy.Minimum, qt.QSizePolicy.Minimum
+            qt.QSizePolicy.Expanding, qt.QSizePolicy.Minimum
         )
 
         # expose API
@@ -575,10 +575,10 @@ class NabuWidget(qt.QWidget):
         self._configuration.hidePaganinInterface()
 
     def getMode(self):
-        return _NabuMode.from_value(self._nabuModeCB.currentText())
+        return _NabuMode(self._nabuModeCB.currentText())
 
     def setMode(self, mode):
-        mode = _NabuMode.from_value(mode)
+        mode = _NabuMode(mode)
         idx = self._nabuModeCB.findText(mode.value)
         self._nabuModeCB.setCurrentIndex(idx)
 
@@ -601,7 +601,7 @@ class NabuWidget(qt.QWidget):
         self._configurationScrollArea.updateGeometry()
 
     def setConfigurationLevel(self, level):
-        level = ConfigurationLevel.from_value(level)
+        level = ConfigurationLevel(level)
         self._configuration_level = level
         self.updateConfigurationFilter()
 
