@@ -13,7 +13,7 @@ from silx.gui import icons as silxicons
 from silx.gui import qt
 from silx.gui.dialog.ImageFileDialog import ImageFileDialog
 from silx.gui.plot import items
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from tomoscan.esrf.scan.utils import get_data
 
 from tomwer.core.process.reconstruction.utils.cor import (
@@ -308,7 +308,7 @@ class _ReconstructionModeGB(qt.QGroupBox):
             raise ValueError("No reconstruction mode selected")
 
     def setReconstructionMode(self, mode: ReconstructionMode | str) -> None:
-        mode = ReconstructionMode.from_value(mode)
+        mode = ReconstructionMode(mode)
         if mode is ReconstructionMode.TILT_CORRECTION:
             self._tiltCorrectionRB.setChecked(True)
         elif mode is ReconstructionMode.VERTICAL:
