@@ -5,6 +5,7 @@ contains gui to select a slice in a volume
 from __future__ import annotations
 
 import logging
+import pint
 import os
 import weakref
 from contextlib import AbstractContextManager
@@ -247,10 +248,10 @@ class VariableSelection(qt.QWidget):
         self._img_width = width
 
     def getScoreMethod(self):
-        return ScoreMethod.from_value(self._scoreMethodCB.currentText())
+        return ScoreMethod(self._scoreMethodCB.currentText())
 
     def setScoreMethod(self, method):
-        method_value = ScoreMethod.from_value(method).value
+        method_value = ScoreMethod(method).value
         index = self._scoreMethodCB.findText(method_value)
         self._scoreMethodCB.setCurrentIndex(index)
 
@@ -670,7 +671,7 @@ class ScorePlot(qt.QWidget):
         :param scores: cor value (float) as key and
                             tuple(url: DataUrl, score: float) as value
         """
-        score_method = ScoreMethod.from_value(score_method)
+        score_method = ScoreMethod(score_method)
         if not update_only_scores:
             self.clear()
             self._scores = scores
@@ -739,7 +740,9 @@ class ScorePlot(qt.QWidget):
         self._plot.getPlotWidget().clear()
         self._varValueWidget.setImgWidth(None)
 
-    def setVoxelSize(self, dim0, dim1, dim2, unit: str | float):
+    def setVoxelSize(
+        self, dim0: pint.Quantity, dim1: pint.Quantity, dim2: pint.Quantity
+    ):
         """
 
         :param dim0:
@@ -747,9 +750,11 @@ class ScorePlot(qt.QWidget):
         :param dim2:
         :param unit:
         """
-        self._voxelSizeW.setValues(dim0=dim0, dim1=dim1, dim2=dim2, unit=unit)
+        self._voxelSizeW.setQuantities(dim0=dim0, dim1=dim1, dim2=dim2)
 
-    def setVolumeSize(self, dim0, dim1, dim2, unit: str | float):
+    def setVolumeSize(
+        self, dim0: pint.Quantity, dim1: pint.Quantity, dim2: pint.Quantity
+    ):
         """
 
         :param dim0:
@@ -757,14 +762,15 @@ class ScorePlot(qt.QWidget):
         :param dim2:
         :param unit:
         """
-        self._volumeSizeW.setValues(dim0=dim0, dim1=dim1, dim2=dim2, unit=unit)
+        self._volumeSizeW.setQuantities(dim0=dim0, dim1=dim1, dim2=dim2)
 
     def getDim0N(self):
         """return the number of elements in dimension 0 according to voxel
         size and volume size"""
         return int(
             numpy.ceil(
-                self._volumeSizeW.getDim0Value()[0] / self._voxelSizeW.getDim0Value()[0]
+                self._volumeSizeW.getDim0Quantity().to_base_units().magnitude
+                / self._voxelSizeW.getDim0Quantity().to_base_units().magnitude
             )
         )
 
@@ -773,7 +779,8 @@ class ScorePlot(qt.QWidget):
         size and volume size"""
         return int(
             numpy.ceil(
-                self._volumeSizeW.getDim1Value()[0] / self._voxelSizeW.getDim1Value()[0]
+                self._volumeSizeW.getDim1Quantity().to_base_units().magnitude
+                / self._voxelSizeW.getDim1Quantity().to_base_units().magnitude
             )
         )
 
@@ -782,7 +789,8 @@ class ScorePlot(qt.QWidget):
         size and volume size"""
         return int(
             numpy.ceil(
-                self._volumeSizeW.getDim2Value()[0] / self._voxelSizeW.getDim2Value()[0]
+                self._volumeSizeW.getDim2Quantity().to_base_units().magnitude
+                / self._voxelSizeW.getDim2Quantity().to_base_units().magnitude
             )
         )
 
