@@ -54,7 +54,7 @@ class SingleAxisStitchingWidget(qt.QWidget, _SingleAxisMixIn):
         # filter stitching types that does belong to the axis (GUI is specific to a given axis. The other have no sense at this level)
         stitching_types = filter(
             lambda s_type: s_type.lower().startswith(self.axis_alias(axis).lower()),
-            StitchingType.values(),
+            [item.value for item in StitchingType],
         )
         for mode in stitching_types:
             self._stitchingTypeCB.addItem(mode)
@@ -84,18 +84,45 @@ class SingleAxisStitchingWidget(qt.QWidget, _SingleAxisMixIn):
         self.sigStitchingTypeChanged.emit(self.getStitchingType().value)
 
     def getStitchingType(self):
-        return StitchingType.from_value(self._stitchingTypeCB.currentText())
+        return StitchingType(self._stitchingTypeCB.currentText())
 
     def setStitchingType(self, mode):
-        mode = StitchingType.from_value(mode)
+        mode = StitchingType(mode)
         idx = self._stitchingTypeCB.findText(mode.value)
         if idx >= 0:
             self._stitchingTypeCB.setCurrentIndex(idx)
 
+    def get_available_pre_processing_stitching_mode(self):
+        pre_proc_modes: tuple[str] = tuple(
+            filter(
+                lambda mode: "preproc" in mode,
+                [
+                    self._stitchingTypeCB.itemText(i_item)
+                    for i_item in range(self._stitchingTypeCB.count())
+                ],
+            )
+        )
+        return tuple([StitchingType(mode) for mode in pre_proc_modes])
+
+    def get_available_post_processing_stitching_mode(self):
+        post_proc_modes: tuple[str] = tuple(
+            filter(
+                lambda mode: "postproc" in mode,
+                [
+                    self._stitchingTypeCB.itemText(i_item)
+                    for i_item in range(self._stitchingTypeCB.count())
+                ],
+            )
+        )
+        return tuple([StitchingType(mode) for mode in post_proc_modes])
+
     def addTomoObj(self, tomo_obj: TomwerObject):
         self._mainWidget.addTomoObj(tomo_obj)
         self._updatePreviewPixelSize()
 
+    def getTomoObjs(self) -> tuple:
+        return self._mainWidget.getTomoObjs()
+
     def removeTomoObj(self, tomo_obj: TomwerObject):
         self._mainWidget.removeTomoObj(tomo_obj)
         self._updatePreviewPixelSize()
@@ -108,10 +135,10 @@ class SingleAxisStitchingWidget(qt.QWidget, _SingleAxisMixIn):
             for tomo_obj in tomo_objs:
                 if (
                     isinstance(tomo_obj, NXtomoScan)
-                    and tomo_obj.x_pixel_size is not None
-                    and tomo_obj.y_pixel_size is not None
+                    and tomo_obj.sample_x_pixel_size is not None
+                    and tomo_obj.sample_y_pixel_size is not None
                 ):
-                    return tomo_obj.x_pixel_size, tomo_obj.y_pixel_size
+                    return tomo_obj.sample_x_pixel_size, tomo_obj.sample_y_pixel_size
                 elif (
                     isinstance(tomo_obj, TomwerVolumeBase)
                     and tomo_obj.voxel_size is not None
