@@ -438,6 +438,11 @@ class _SingleAxisStitchingWindow(
         # update to force overwrite
         config["output"]["overwrite_results"] = True
 
+        # avoid any recalculation of the axis position. So the preview is accurate
+        config["output"]["axis_0_params"] = ""
+        config["output"]["axis_1_params"] = ""
+        config["output"]["axis_2_params"] = ""
+
         # clean current preview to notify some calculation is going on
         preview_plot = self._widget._mainWidget._previewPlot
         preview_plot._waitingOverlay.show()
@@ -535,6 +540,9 @@ class _SingleAxisStitchingWindow(
         self._editTomoObjSecondAxisPositionsWidget.addTomoObj(tomo_obj)
         self.getRawDisplayPlot().addTomoObj(tomo_obj=tomo_obj)
 
+    def getTomoObjs(self) -> tuple:
+        return self._widget.getTomoObjs()
+
     def removeTomoObj(self, tomo_obj):
         self._widget.removeTomoObj(tomo_obj)
         self.getRawDisplayPlot().removeTomoObj(tomo_obj=tomo_obj)
@@ -577,6 +585,18 @@ class _SingleAxisStitchingWindow(
             level >= ConfigurationLevel.ADVANCED
         )
 
+    def setPreProcessingOutput(self, *args, **kwargs):
+        self._outputWidget.setPreProcessingOutput(*args, **kwargs)
+
+    def setPostProcessingOutput(self, *args, **kwargs):
+        self._outputWidget.setPostProcessingOutput(*args, **kwargs)
+
+    def get_available_pre_processing_stitching_mode(self):
+        return self._widget.get_available_pre_processing_stitching_mode()
+
+    def get_available_post_processing_stitching_mode(self):
+        return self._widget.get_available_post_processing_stitching_mode()
+
 
 class YStitchingWindow(_SingleAxisStitchingWindow, axis=1):
     pass
