@@ -361,7 +361,7 @@ class EditableOrderedTomoObjWidget(AxisOrderedTomoObjWidget):
             [self._tomoObjsTableView.model().getTomoObj(item) for item in selection]
         )
 
-    def _callbackAddTomoObj(self):
+    def _callbackAddTomoObj(self) -> tuple[TomwerObject]:
         dialog = qt.QFileDialog()
         dialog.setFileMode(qt.QFileDialog.ExistingFiles)
         dialog.setNameFilters(
@@ -372,9 +372,9 @@ class EditableOrderedTomoObjWidget(AxisOrderedTomoObjWidget):
 
         if not dialog.exec_():
             dialog.close()
-            return
+            return ()
         elif len(dialog.selectedFiles()) == 0:
-            return
+            return ()
         else:
             tomo_objs = []
             for file in dialog.selectedFiles():
@@ -386,6 +386,7 @@ class EditableOrderedTomoObjWidget(AxisOrderedTomoObjWidget):
                     tomo_objs.extend(new_objs)
             for tomo_obj in tomo_objs:
                 self.addTomoObj(tomo_obj=tomo_obj, trigger_callbacks=True)
+            return tuple(tomo_objs)
 
     def _callbackRemoveSelectedTomoObj(self):
         obj_to_remove = self.getSelectedTomoObjs()
