@@ -247,7 +247,7 @@ class NXTomomillOutputDirSelector(qt.QWidget):
         tooltip = """Define the output directory of the nexus (.nx) file. Options are:
         \n - same folder as scan: create the NXtomos at the same level as the bliss input file or spec folder
         \n - 'PROCESSED_DATA' folder: create NXtomos on the default 'PROCESSED_DATA' folder (bliss default folder, nearby the 'raw' folder).
-        \n - user defined folder: users can provide their own folders using keywords for string formatting such as 'scan_dir_name', 'scan_basename' or 'scan_parent_dir_basename'
+        \n - user defined folder: users can provide their own folders using keywords for string formatting such as 'scan_dir_name', 'scan_basename' or 'scan_parent_dir_basename', 'scan_file_name' and 'scan_entry'
         """
 
         # output dir is the folder containing the .nx file
@@ -437,7 +437,13 @@ class OutputVolumeDefinition(qt.QWidget):
         # output file or folder
         self._outputFileLabel = qt.QLabel("", self)
         self.layout().addWidget(self._outputFileLabel, 1, 0, 1, 1)
-        self._outputFileQLE = QLFileSystem("stitched_volume.hdf5", parent=None)
+        self._outputFileQLE = QLFileSystem(
+            os.path.join(
+                os.getcwd(),
+                "stitched_volume.hdf5",
+            ),
+            parent=None,
+        )
         self.layout().addWidget(self._outputFileQLE, 1, 1, 1, 1)
         self._selectPB = qt.QPushButton("select", self)
         self.layout().addWidget(self._selectPB, 1, 2, 1, 1)
